DisplayBrightnessPlatform class abstract
The interface that implementations of display_brightness must implement.
Platform implementations should extend this class rather than implement it,
as implement does not consider newly added methods to be breaking changes.
Extending this class (using extends) ensures that the subclass will get
the default implementation, while platform implementations that implements
this interface will be broken by newly added DisplayBrightnessPlatform
methods.
- Inheritance
-
- Object
- PlatformInterface
- DisplayBrightnessPlatform
Constructors
- DisplayBrightnessPlatform()
- Constructs a DisplayBrightnessPlatform.
Properties
- brightness → double?
-
Returns the current effective brightness (0.0–1.0), or
nullif the system brightness setting could not be read.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
onBrightnessChanged
→ Stream<
double> -
A broadcast stream that emits brightness values (0.0–1.0)
whenever the screen brightness changes.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Releases all native resources.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setBrightness(
double value) → void - Sets the app-level brightness.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ DisplayBrightnessPlatform
-
The instance of DisplayBrightnessPlatform to use.
getter/setter pair